@@ -15,7 +15,8 @@
    (eval . (put 'with-directory-excursion 'scheme-indent-function 1))
    (eval . (put 'package 'scheme-indent-function 1))
    (eval . (put 'substitute-keyword-arguments 'scheme-indent-function 1))
-   (eval . (put 'with-error-handling 'scheme-indent-function 0))))
+   (eval . (put 'with-error-handling 'scheme-indent-function 0))
+   (eval . (put 'with-mutex 'scheme-indent-function 1))))
  (emacs-lisp-mode . ((indent-tabs-mode . nil)))
  (texinfo-mode    . ((indent-tabs-mode . nil)
                      (fill-column . 72))))
