@@ -45,18 +45,25 @@
         'configure 'patch-makefile-SHELL
         (lambda _
           (patch-makefile-SHELL "include/buildmacros"))
-        (alist-replace
-         'check
-         (lambda _
-           (system* "make" "tests" "-C" "test")
+        ,(if (%current-target-system)
+             '%standard-phases
+             '(alist-replace 'check
+                             (lambda _
+                               (system* "make" "tests" "-C" "test")
 
-           ;; XXX: Ignore the test result since this is
-           ;; dependent on the underlying file system.
-           #t)
-         %standard-phases))))
+                               ;; XXX: Ignore the test result since this is
+                               ;; dependent on the underlying file system.
+                               #t)
+                             %standard-phases)))))
     (inputs `(("attr" ,attr)
-              ("gettext" ,guix:gettext)
-              ("perl" ,perl)))
+
+              ;; Perl is needed to run tests; remove it from cross builds.
+              ,@(if (%current-target-system)
+                    '()
+                    `(("perl" ,perl)))))
+    (native-inputs
+     `(("gettext" ,guix:gettext)))
+
     (home-page
      "http://savannah.nongnu.org/projects/acl")
     (synopsis
