@@ -60,14 +60,14 @@ multiplication routines such as Toom–Cook and the FFT. ")
 (define-public fplll
   (package
    (name "fplll")
-   (version "4.0.1")
+   (version "4.0.2")
    (source (origin
             (method url-fetch)
             (uri (string-append
                   "http://perso.ens-lyon.fr/damien.stehle/fplll/libfplll-"
                   version ".tar.gz"))
             (sha256 (base32
-                     "122bpqdlikshhd7nmq0l5qfc0agyk7x21gvplv1l9hb77l8cy9rw"))))
+                     "0zkifm4s77cl2qib905lxpwvlwf6liy8q7bnmvfdfyz0fbgxl8z8"))))
    (build-system gnu-build-system)
    (inputs `(("gmp" ,gmp)
              ("mpfr" ,mpfr)))
@@ -92,7 +92,7 @@ solve the shortest vector problem.")
         "18qf6jzz1r3mzb5qynywv4xx3z9g61hgkbpkdrhbgqh2g7jhgfc5"))))
     (build-system gnu-build-system)
     (home-page "http://www.gnu.org/software/gsl/")
-    (synopsis "The GNU Scientific Library, a large numerical library")
+    (synopsis "Numerical library for C and C++")
     (description
      "The GNU Scientific Library (GSL) is a numerical library for C
 and C++ programmers.  It is free software under the GNU General
@@ -120,26 +120,25 @@ extensive test suite.")
              ("perl" ,perl)
              ("readline" ,readline)))
    (arguments
-    (lambda (system)
-      `(#:make-flags '("gp")
-;; FIXME: building the documentation requires tex; once this is available,
-;; replace "gp" by "all"
-        #:test-target "dobench"
-        #:phases
-        (alist-replace
-         'configure
-         (lambda* (#:key inputs outputs #:allow-other-keys)
-           (let ((out (assoc-ref outputs "out"))
-                 (readline (assoc-ref inputs "readline"))
-                 (gmp (assoc-ref inputs "gmp")))
-             (zero?
-              (system* "./Configure"
-                       (string-append "--prefix=" out)
-                       (string-append "--with-readline=" readline)
-                       (string-append "--with-gmp=" gmp)))))
-;; FIXME: readline and gmp will be detected automatically in the next
-;; stable release
-         %standard-phases))))
+    '(#:make-flags '("gp")
+      ;; FIXME: building the documentation requires tex; once this is available,
+      ;; replace "gp" by "all"
+      #:test-target "dobench"
+      #:phases
+      (alist-replace
+       'configure
+       (lambda* (#:key inputs outputs #:allow-other-keys)
+         (let ((out (assoc-ref outputs "out"))
+               (readline (assoc-ref inputs "readline"))
+               (gmp (assoc-ref inputs "gmp")))
+           (zero?
+            (system* "./Configure"
+                     (string-append "--prefix=" out)
+                     (string-append "--with-readline=" readline)
+                     (string-append "--with-gmp=" gmp)))))
+       ;; FIXME: readline and gmp will be detected automatically in the next
+       ;; stable release
+       %standard-phases)))
    (synopsis "PARI/GP, a computer algebra system for number theory")
    (description
     "PARI/GP is a widely used computer algebra system designed for fast
@@ -178,7 +177,7 @@ PARI is also available as a C library to allow for faster computations.")
                                     (string-append "--prefix=" out)))))
                       %standard-phases)))
     (home-page "http://www.gnu.org/software/bc/")
-    (synopsis "GNU software calculator")
+    (synopsis "Arbitrary precision numeric processing language")
     (description
      "bc is an arbitrary precision numeric processing language. Syntax
 is similar to C, but differs in many substantial areas. It supports
