@@ -42,8 +42,7 @@
     (inputs
      `(("patch/gets" ,(search-patch "cpio-gets-undeclared.patch"))))
     (home-page "https://www.gnu.org/software/cpio/")
-    (synopsis
-     "A program to create or extract from cpio archives")
+    (synopsis "Manage cpio and tar file archives")
     (description
      "GNU Cpio copies files into or out of a cpio or tar archive. The
 archive can be another file on the disk, a magnetic tape, or a pipe.
@@ -55,4 +54,4 @@ default, cpio creates binary format archives, for compatibility with
 older cpio programs. When extracting from archives, cpio automatically
 recognizes which kind of archive it is reading and can read archives
 created on machines with a different byte-order.")
-    (license gpl3+)))
\ No newline at end of file
+    (license gpl3+)))
