@@ -32,14 +32,14 @@
 (define-public gdb
   (package
     (name "gdb")
-    (version "7.5")
+    (version "7.6")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/gdb/gdb-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "0chrws5ga90b50kp06yll6zy42fhnx9yr87r4i7swsc369fc8y6i"))))
+               "06yzggy97qka6fs1vdz4q0d2fgrpm3iaj7dzvf1ww377bvryh454"))))
     (build-system gnu-build-system)
     (arguments
      '(#:phases (alist-cons-after
@@ -57,7 +57,7 @@
        ("texinfo" ,texinfo)
        ("dejagnu" ,dejagnu)))
     (home-page "http://www.gnu.org/software/gdb/")
-    (synopsis "GDB, the GNU Project debugger")
+    (synopsis "The GNU debugger")
     (description
      "GDB, the GNU Project debugger, allows you to see what is going
 on `inside' another program while it executes -- or what another
