@@ -26,36 +26,30 @@
 (define-public gettext
   (package
     (name "gettext")
-    (version "0.18.1.1")
-    (source
-     (origin
-      (method url-fetch)
-      (uri (string-append "mirror://gnu/gettext/gettext-"
-                          version ".tar.gz"))
-      (sha256
-       (base32
-        "1sa3ch12qxa4h3ya6hkz119yclcccmincl9j20dhrdx5mykp3b4k"))))
+    (version "0.18.3")
+    (source (origin
+             (method url-fetch)
+             (uri (string-append "mirror://gnu/gettext/gettext-"
+                                 version ".tar.gz"))
+             (sha256
+              (base32
+               "0j7rp56c61j4k1bz1xdc041hzv7186yyzhbp95fmc0zq7l2c3wrn"))))
     (build-system gnu-build-system)
     (arguments
-     `(#:patches (list (assoc-ref %build-inputs "patch/gets"))
-       #:phases (alist-cons-before
+     `(#:phases (alist-cons-before
                  'check 'patch-tests
                  (lambda* (#:key inputs #:allow-other-keys)
-                   (let ((bash (assoc-ref inputs "bash")))
+                   (let ((bash (which "sh")))
                      (substitute* (find-files "gettext-tools/tests"
                                               "^msgexec-[0-9]")
                        (("#![[:blank:]]/bin/sh")
-                        (format #f "#!~a/bin/sh" bash)))
+                        (format #f "#!~a" bash)))
                      (substitute* (find-files "gettext-tools/gnulib-tests"
                                               "posix_spawn")
                        (("/bin/sh")
-                        (format #f "~a/bin/bash" bash)))))
+                        bash))))
                  %standard-phases)))
-    (inputs
-     `(("patch/gets"
-        ,(search-patch "gettext-gets-undeclared.patch"))))
-    (home-page
-     "http://www.gnu.org/software/gettext/")
+    (home-page "http://www.gnu.org/software/gettext/")
     (synopsis "Tools and documentation for translation")
     (description
      "Usually, programs are written and documented in English, and use
