@@ -23,10 +23,12 @@
   #:use-module (guix build-system gnu)
   #:use-module ((gnu packages compression)
                 #:renamer (symbol-prefix-proc 'guix:))
+  #:use-module (gnu packages)
   #:use-module (gnu packages nettle)
   #:use-module (gnu packages guile)
   #:use-module (gnu packages perl)
-  #:use-module (gnu packages which))
+  #:use-module (gnu packages which)
+  #:use-module (gnu packages pkg-config))
 
 (define-public libtasn1
   (package
@@ -52,22 +54,30 @@ portable, and only require an ANSI C89 platform.")
 (define-public gnutls
   (package
     (name "gnutls")
-    (version "3.1.9.1")
+    (version "3.2.1")
     (source (origin
              (method url-fetch)
              (uri
               ;; Note: Releases are no longer on ftp.gnu.org since the
               ;; schism (after version 3.1.5).
-              (string-append "mirror://gnupg/gnutls/v3.1/gnutls-"
+              (string-append "mirror://gnupg/gnutls/v3.2/gnutls-"
                              version ".tar.xz"))
              (sha256
               (base32
-               "0gkwhz7sypfy39jfj2yzrngbxq5j9l9smqc89mqlqsh25spc8009"))))
+               "1zi2kq3vcbqdy9khl7r6pgk4hgwibniasm9k6siasdvqjijq3ymb"))))
     (build-system gnu-build-system)
+    (arguments
+      `(#:patches (list (assoc-ref %build-inputs
+                                   "patch/fix-tests"))
+        #:patch-flags '("-p0")))
+    (native-inputs
+     `(("pkg-config" ,pkg-config)))
     (inputs
      `(("guile" ,guile-2.0)
        ("zlib" ,guix:zlib)
-       ("perl" ,perl)))
+       ("perl" ,perl)
+       ("patch/fix-tests"
+        ,(search-patch "gnutls-fix-tests-on-32-bits-system.patch"))))
     (propagated-inputs
      `(("libtasn1" ,libtasn1)
        ("nettle" ,nettle)
