@@ -22,13 +22,12 @@
   #:use-module (web client)
   #:use-module (web response)
   #:use-module (ice-9 regex)
-  #:use-module (ice-9 rdelim)
   #:use-module (ice-9 match)
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-11)
   #:use-module (srfi srfi-26)
   #:use-module (system foreign)
-  #:use-module (guix web)
+  #:use-module (guix http-client)
   #:use-module (guix ftp-client)
   #:use-module (guix ui)
   #:use-module (guix utils)
@@ -49,6 +48,7 @@
             gnu-package-logo
             gnu-package-doc-category
             gnu-package-doc-summary
+            gnu-package-doc-description
             gnu-package-doc-urls
             gnu-package-download-url
 
@@ -81,6 +81,11 @@
                   "viewvc/*checkout*/gnumaint/"
                   "gnupackages.txt?root=womb")))
 
+(define %gsrc-package-list-url
+  ;; This file is normally kept in sync with GSRC.
+  ;; See <http://lists.gnu.org/archive/html/bug-guix/2013-04/msg00117.html>.
+  (string->uri "http://www.gnu.org/software/gsrc/MANIFEST.rec"))
+
 (define-record-type* <gnu-package-descriptor>
   gnu-package-descriptor
   make-gnu-package-descriptor
@@ -92,75 +97,48 @@
   (copyright-holder gnu-package-copyright-holder)
   (savannah         gnu-package-savannah)
   (fsd              gnu-package-fsd)
-  (language         gnu-package-language)
+  (language         gnu-package-language)         ; list of strings
   (logo             gnu-package-logo)
   (doc-category     gnu-package-doc-category)
   (doc-summary      gnu-package-doc-summary)
-  (doc-urls         gnu-package-doc-urls)
+  (doc-description  gnu-package-doc-description)  ; taken from GSRC
+  (doc-urls         gnu-package-doc-urls)         ; list of strings
   (download-url     gnu-package-download-url))
 
 (define (official-gnu-packages)
   "Return a list of records, which are GNU packages."
-  (define (group-package-fields port state)
+  (define (read-records port)
     ;; Return a list of alists.  Each alist contains fields of a GNU
     ;; package.
-    (let ((line        (read-line port))
-          (field-rx    (make-regexp "^([[:graph:]]+): (.*)$"))
-          (doc-urls-rx (make-regexp "^doc-url: (.*)$"))
-          (end-rx      (make-regexp "^# End. .+Do not remove this line.+")))
+    (let loop ((alist  (recutils->alist port))
+               (result '()))
+      (if (null? alist)
+          (reverse result)
+          (loop (recutils->alist port)
+                (cons alist result)))))
 
-      (define (match-field str)
-        ;; Packages are separated by empty strings.  If STR is an
-        ;; empty string, create a new list to store fields of a
-        ;; different package.  Otherwise, match and create a key-value
-        ;; pair.
-        (match str
-          (""
-           (group-package-fields port (cons '() state)))
-          (str
-           (cond ((regexp-exec doc-urls-rx str)
-                  =>
-                  (lambda (match)
-                    (if (equal? (assoc-ref (first state) "doc-urls") #f)
-                        (group-package-fields
-                         port (cons (cons (cons "doc-urls"
-                                                (list
-                                                 (match:substring match 1)))
-                                          (first state))
-                                    (drop state 1)))
-                        (group-package-fields
-                         port (cons (cons (cons "doc-urls"
-                                                (cons (match:substring match 1)
-                                                      (assoc-ref (first state)
-                                                                 "doc-urls")))
-                                          (assoc-remove! (first state)
-                                                         "doc-urls"))
-                                    (drop state 1))))))
-                 ((regexp-exec field-rx str)
-                  =>
-                  (lambda (match)
-                    (group-package-fields
-                     port (cons (cons (cons (match:substring match 1)
-                                            (match:substring match 2))
-                                      (first state))
-                                (drop state 1)))))
-                 (else (group-package-fields port state))))))
+  (define gsrc-description
+    (let ((gsrc (read-records (http-fetch %gsrc-package-list-url
+                                          #:text? #t))))
+      (lambda (name)
+        ;; Return the description found in GSRC for package NAME, or #f.
+        (and=> (find (lambda (alist)
+                       (equal? name (assoc-ref alist "Upstream_name")))
+                     gsrc)
+               (cut assoc-ref <> "Blurb")))))
 
-      (if (or (eof-object? line)
-              (regexp-exec end-rx line)) ; don't include dummy fields
-          (remove null-list? state)
-          (match-field line))))
-
-  (reverse
-   (map (lambda (alist)
-          (alist->record alist
-                         make-gnu-package-descriptor
-                         (list "package" "mundane-name" "copyright-holder"
-                               "savannah" "fsd" "language" "logo"
-                               "doc-category" "doc-summary" "doc-urls"
-                               "download-url")))
-        (group-package-fields (http-fetch %package-list-url #:text? #t)
-                              '(())))))
+  (map (lambda (alist)
+         (let ((name (assoc-ref alist "package")))
+           (alist->record `(("description" . ,(gsrc-description name))
+                            ,@alist)
+                          make-gnu-package-descriptor
+                          (list "package" "mundane-name" "copyright-holder"
+                                "savannah" "fsd" "language" "logo"
+                                "doc-category" "doc-summary" "description"
+                                "doc-url"
+                                "download-url")
+                          '("doc-url" "language"))))
+       (read-records (http-fetch %package-list-url #:text? #t))))
 
 (define (find-packages regexp)
   "Find GNU packages which satisfy REGEXP."
@@ -274,8 +252,10 @@ pairs.  Example: (\"mit-scheme-9.0.1\" . \"/gnu/mit-scheme/stable.pkg/9.0.1\").
                               files)
                   result))))))))
 
-(define (latest-release project)
-  "Return (\"FOO-X.Y\" . \"/bar/foo\") or #f."
+(define* (latest-release project
+                         #:key (ftp-open ftp-open) (ftp-close ftp-close))
+  "Return (\"FOO-X.Y\" . \"/bar/foo\") or #f.  Use FTP-OPEN and FTP-CLOSE to
+open (resp. close) FTP connections; this can be useful to reuse connections."
   (define (latest a b)
     (if (version>? a b) a b))
 
@@ -303,14 +283,18 @@ pairs.  Example: (\"mit-scheme-9.0.1\" . \"/gnu/mit-scheme/stable.pkg/9.0.1\").
                                       (release-file project file))
                                      (_ #f))
                                     entries)))
+             (ftp-close conn)
              (and=> (reduce latest #f files)
                     (cut cons <> directory))))
           ((subdirs ...)
            ;; Assume that SUBDIRS correspond to versions, and jump into the
            ;; one with the highest version number.
            (let ((target (reduce latest #f subdirs)))
-             (and target
-                  (loop (string-append directory "/" target))))))))))
+             (if target
+                 (loop (string-append directory "/" target))
+                 (begin
+                   (ftp-close conn)
+                   #f)))))))))
 
 (define %package-name-rx
   ;; Regexp for a package name, e.g., "foo-X.Y".  Since TeXmacs uses
@@ -341,16 +325,19 @@ pairs.  Example: (\"mit-scheme-9.0.1\" . \"/gnu/mit-scheme/stable.pkg/9.0.1\").
          (_ #f))))
 
 (define* (download-tarball store project directory version
-                           #:optional (archive-type "gz"))
+                           #:key (archive-type "gz")
+                                 (key-download 'interactive))
   "Download PROJECT's tarball over FTP and check its OpenPGP signature.  On
-success, return the tarball file name."
+success, return the tarball file name.  KEY-DOWNLOAD specifies a download
+policy for missing OpenPGP keys; allowed values: 'interactive' (default),
+'always', and 'never'."
   (let* ((server  (ftp-server/directory project))
          (base    (string-append project "-" version ".tar." archive-type))
          (url     (string-append "ftp://" server "/" directory "/" base))
          (sig-url (string-append url ".sig"))
          (tarball (download-to-store store url))
          (sig     (download-to-store store sig-url)))
-    (let ((ret (gnupg-verify* sig tarball)))
+    (let ((ret (gnupg-verify* sig tarball #:key-download key-download)))
       (if ret
           tarball
           (begin
@@ -359,9 +346,11 @@ success, return the tarball file name."
             (warning (_ "(could be because the public key is not in your keyring)~%"))
             #f)))))
 
-(define (package-update store package)
+(define* (package-update store package #:key (key-download 'interactive))
   "Return the new version and the file name of the new version tarball for
-PACKAGE, or #f and #f when PACKAGE is up-to-date."
+PACKAGE, or #f and #f when PACKAGE is up-to-date.  KEY-DOWNLOAD specifies a
+download policy for missing OpenPGP keys; allowed values: 'always', 'never',
+and 'interactive' (default)."
   (match (package-update-path package)
     ((version . directory)
      (let-values (((name)
@@ -372,7 +361,8 @@ PACKAGE, or #f and #f when PACKAGE is up-to-date."
                               (file-extension (origin-uri source)))
                          "gz"))))
        (let ((tarball (download-tarball store name directory version
-                                        archive-type)))
+                                        #:archive-type archive-type
+                                        #:key-download key-download)))
          (values version tarball))))
     (_
      (values #f #f))))
