@@ -1,5 +1,5 @@
 ;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -25,7 +25,8 @@
   #:use-module (guix utils)
   #:use-module (guix base32)
   #:use-module (guix derivations)
-  #:use-module ((guix packages) #:select (package-derivation))
+  #:use-module ((guix packages)
+                #:select (package-derivation package-native-search-paths))
   #:use-module (gnu packages bootstrap)
   #:use-module (ice-9 match)
   #:use-module (srfi srfi-1)
@@ -50,6 +51,13 @@
               (list name (package-derivation %store package))))
             (@@ (gnu packages base) %boot0-inputs))))
 
+(define %bootstrap-search-paths
+  ;; Search path specifications that go with %BOOTSTRAP-INPUTS.
+  (append-map (match-lambda
+               ((name package _ ...)
+                (package-native-search-paths package)))
+              (@@ (gnu packages base) %boot0-inputs)))
+
 (define network-reachable?
   (false-if-exception (getaddrinfo "www.gnu.org" "80" AI_NUMERICSERV)))
 
@@ -83,7 +91,8 @@
          (build    (gnu-build %store "hello-2.8" tarball
                               %bootstrap-inputs
                               #:implicit-inputs? #f
-                              #:guile %bootstrap-guile))
+                              #:guile %bootstrap-guile
+                              #:search-paths %bootstrap-search-paths))
          (out      (derivation-path->output-path build)))
     (and (build-derivations %store (list (pk 'hello-drv build)))
          (valid-path? %store out)
@@ -93,7 +102,3 @@
 
 
 (exit (= (test-runner-fail-count (test-runner-current)) 0))
-
-;;; Local Variables:
-;;; eval: (put 'test-assert 'scheme-indent-function 1)
-;;; End:
